@@ -66,7 +66,8 @@ def create_parser():
     parser.add_argument(
         "--no-patches",
         action="store_true",
-        help="Don't apply automatic patches to generated output")
+        help="Don't apply automatic patches to generated output",
+    )
     parser.add_argument(
         "--no-curdir",
         action="store_true",
